@@ -138,7 +138,7 @@ log_matcher_posix_re_feed_backrefs(LogMatcher *s, LogMessage *msg, gint value_ha
 
   for (i = 0; i < RE_MAX_MATCHES && matches[i].rm_so != -1; i++)
     {
-      if (value_handle != LM_V_NONE)
+      if (value_handle != LM_V_NONE && !log_msg_is_handle_macro(value_handle))
         {
           log_msg_set_match_indirect(msg, i, value_handle, 0, matches[i].rm_so, matches[i].rm_eo - matches[i].rm_so);
         }
@@ -582,7 +582,7 @@ log_matcher_pcre_re_feed_backrefs(LogMatcher *s, LogMessage *msg, gint value_han
 
   for (i = 0; i < (RE_MAX_MATCHES) && i < match_num; i++)
     {
-      if (value_handle != LM_V_NONE)
+      if (value_handle != LM_V_NONE && !log_msg_is_handle_macro(value_handle))
         {
           log_msg_set_match_indirect(msg, i, value_handle, 0, matches[2 * i], matches[2 * i + 1] - matches[2 * i]);
         }
@@ -811,8 +811,8 @@ static void
 log_matcher_pcre_re_free(LogMatcher *s)
 {
   LogMatcherPcreRe *self = (LogMatcherPcreRe *) s;
+  pcre_free(self->extra);
   pcre_free(self->pattern);
-
 }
 
 LogMatcher *
